## {{ cookiecutter.project_name }}

A `{{ cookiecutter.project_type }}` plugin for [Grove](https://www.github.com/hashicorp-forge/grove),
providing support for {{ cookiecutter.provider_name }} {{ cookiecutter.provider_product }}.
